@@ -188,6 +188,10 @@
      (remove-waiter (wait-list usocket) usocket))
   (socket:socket-server-close (socket usocket)))
 
+(defmethod socket-shutdown ((usocket stream-usocket) direction)
+  (with-mapped-conditions (usocket)
+    (socket:socket-stream-shutdown (socket usocket) direction)))
+
 (defmethod get-local-name ((usocket stream-usocket))
   (multiple-value-bind
       (address port)
@@ -246,7 +250,7 @@
                             (socket:socket-status request-list)))
              (sockets (wait-list-waiters wait-list)))
         (do* ((x (pop sockets) (pop sockets))
-              (y (cdr (pop status-list)) (cdr (pop status-list))))
+              (y (pop status-list) (pop status-list)))
              ((null x))
           (when (member y '(T :INPUT))
             (setf (state x) :READ)))
